binarise: Binarise a numeric array
Description
This function binarises an array, setting all nonzero elements to unity.Arguments
x
An object that can be coerced to an array, or for which a
morph method exists. Value
- A morphed array with the same dimensions as the original array.
See Also
morph for the function underlying this operation, and
erode for mathematical morphology functions.